//
//  HWTableViewController.m
//  HWTableView
//
//  Created by qibin wang on 16/3/4.
//  Copyright © 2016年 qibin wang. All rights reserved.
//

#import "HWTableViewController.h"
#import "HWTableViewCell.h"
#import "HWFrameModel.h"
#import "HWModel.h"
#import "HWAudioPlayerManger.h"
#import "HWSecondViewController.h"

@interface HWTableViewController ()

@property (nonatomic, strong) NSArray<HWFrameModel *> *infoArray;
@property (nonatomic, assign) NSInteger row;

@end

@implementation HWTableViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    //初始化信息
    [self initInfo];

    //获取数据
    [self getInfo];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    
    //如UITextField、UITextView、UIWebView等控件自带UIMenuController菜单栏，如果其他界面不想显示自定义的菜单，可清空menuItems
//    [UIMenuController sharedMenuController].menuItems = @[];
}

- (void)initInfo
{
    self.tableView.backgroundColor = [UIColor whiteColor];
    
    //添加长按事件
    UILongPressGestureRecognizer *gesture = [[UILongPressGestureRecognizer alloc] initWithTarget:self action:@selector(didLongPressTableViewCell:)];
    gesture.minimumPressDuration = 1.0;
    [self.tableView addGestureRecognizer:gesture];
    
    //注册通知
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(menuWillShow:) name:UIMenuControllerWillShowMenuNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(menuDidShow:) name:UIMenuControllerDidShowMenuNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(menuWillHide:) name:UIMenuControllerWillHideMenuNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(menuDidHide:) name:UIMenuControllerDidHideMenuNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(menuFrameDidChange:) name:UIMenuControllerMenuFrameDidChangeNotification object:nil];
}

- (void)getInfo
{
    //模拟数据
    NSArray *array = @[
                       @{@"name" : @"小a", @"icon" : @"hero", @"text" : @"这里是文本，长按可复制、打印、语音播放文本。\n这里是文本，长按可复制、打印、语音播放文本。\n这里是文本，长按可复制、打印、语音播放文本。", @"picture" : @"hero"},
                       @{@"name" : @"小b", @"icon" : @"icon_p", @"text" : @"肥灰驴和灰肥驴，\n肥灰驴，灰肥驴，\n肥灰驴比灰肥驴肥，\n灰肥驴比肥灰驴灰。", @"picture" : @"hero"},
                       @{@"name" : @"小c名字很特别", @"icon" : @"icon_y", @"text" : @"没有配图，lalala，hello world，UIMenuController。"},
                       @{@"name" : @"小d", @"icon" : @"icon_s", @"picture" : @"hero"}];
    
    //解析数据，转模型保存
    NSMutableArray *tempArray = [NSMutableArray array];
    for (NSDictionary *dict in array) {
        HWModel *model = [HWModel modelWithDict:dict];
        HWFrameModel *frameModel = [[HWFrameModel alloc] init];
        frameModel.model = model;
        [tempArray addObject:frameModel];
    }
    _infoArray = [tempArray copy];
}

#pragma mark - UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return _infoArray.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    HWTableViewCell *cell = [HWTableViewCell cellWIthTableView:tableView];
    
    cell.frameModel = _infoArray[indexPath.row];
    
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return [_infoArray[indexPath.row] cellHeight];
}

//tableViewCell点击事件
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [self presentViewController:[[HWSecondViewController alloc] init] animated:YES completion:nil];
}

//tableViewCell长按事件
- (void)didLongPressTableViewCell:(UILongPressGestureRecognizer *)gesture
{
    if (gesture.state == UIGestureRecognizerStateBegan) {
        //获取到点击的位置
        NSIndexPath *indexPath = [self.tableView indexPathForRowAtPoint:[gesture locationInView:self.tableView]];
        if(indexPath == nil) return;
        
        //获取UIMenuController对象
        UIMenuController *menu = [UIMenuController sharedMenuController];
        //设置箭头方向
//        menu.arrowDirection = UIMenuControllerArrowLeft;
        
        if (menu.isMenuVisible) {
            [menu setMenuVisible:NO animated:YES];
            
        }else {
            HWTableViewCell *cell = [self.tableView cellForRowAtIndexPath:indexPath];
            _row = indexPath.row;
            [cell becomeFirstResponder];
        
            //自定义item
            UIMenuItem *printf = [[UIMenuItem alloc] initWithTitle:@"打印" action:@selector(printf:)];
            UIMenuItem *audio = [[UIMenuItem alloc] initWithTitle:@"语音" action:@selector(audioPlay:)];
            menu.menuItems = @[printf, audio];
            
            [menu setTargetRect:CGRectMake(0, cell.frame.size.height * 0.5, cell.frame.size.width, cell.frame.size.height) inView:cell];
            [menu setMenuVisible:YES animated:YES];
        }
    }
}

//复制文字到剪切板
- (void)copy:(UIMenuController *)menu
{
    NSString *str = [[_infoArray[_row] model] text];
    if (!str) return;
    
    [UIPasteboard generalPasteboard].string = str;
}

//打印文本内容
- (void)printf:(UIMenuController *)menu
{
    NSLog(@"printf: %@", [[_infoArray[_row] model] text]);
}

//语音播放文本内容
- (void)audioPlay:(UIMenuController *)menu
{
    [[HWAudioPlayerManger shareManager] playWithString:[[_infoArray[_row] model] text]];
}

//拖动隐藏
- (void)scrollViewWillBeginDragging:(UIScrollView *)scrollView
{
    [[UIMenuController sharedMenuController] setMenuVisible:NO animated:YES];
}

//允许执行的操作
//- (BOOL)canPerformAction:(SEL)action withSender:(id)sender
//{
//    NSLog(@"SEL : %@", NSStringFromSelector(action));
//
//    if (action == @selector(copy:) || action == @selector(printf:) || action == @selector(audioPlay:)) {
//        return YES;
//    }
//
//    return NO;
//}

#pragma mark - UIMenuControllerNotification
- (void)menuWillShow:(NSNotification *)notification
{
    NSLog(@"menuWillShow");
}

- (void)menuDidShow:(NSNotification *)notification
{
    NSLog(@"menuDidShow");
}

- (void)menuWillHide:(NSNotification *)notification
{
    NSLog(@"menuWillHide");
}

- (void)menuDidHide:(NSNotification *)notification
{
    NSLog(@"menuDidHide");
}

- (void)menuFrameDidChange:(NSNotification *)notification
{
    NSLog(@"menuFrameDidChange");
}

- (void)dealloc
{
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

@end
